@@ -15,9 +15,9 @@
 import logging
 
 from horizon.utils.memoized import memoized
-from openstack_dashboard.api import base
 from keystoneauth1.identity.generic.token import Token
 from keystoneauth1.session import Session
+from openstack_dashboard.api import base
 from venusclient.v1 import client
 
 LOG = logging.getLogger(__name__)
@@ -41,8 +41,13 @@ def log_storage_days(request):
     return venusclient(request).config.get_days()
 
 
-def logs(request, start_time, end_time, page_size, page_num):
+def logs(request, start_time, end_time, page_size, page_num, module_name,
+         host_name, program_name, level):
     return venusclient(request).search.get_log(start_time=start_time,
                                                end_time=end_time,
                                                page_size=page_size,
-                                               page_num=page_num)
+                                               page_num=page_num,
+                                               module_name=module_name,
+                                               host_name=host_name,
+                                               program_name=program_name,
+                                               level=level)
